@@ -8,36 +8,38 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
-set -u
+. ./include.ctest.sh
 
-label="grib_suppressed-test"
+label="grib_suppressed_test"
 
 tempErr=temp.${label}.err
 tempFilt=temp.${label}.filt
 tempRef=temp.${label}.ref
 sample2=$ECCODES_SAMPLES_PATH/GRIB2.tmpl
 
-cat > $tempFilt <<EOF
-  meta a_deprecated_key suppressed(typeOfOriginalFieldValues);
-  print "[a_deprecated_key]";
-EOF
-
-set +e
-${tools_dir}/grib_filter $tempFilt $sample2 2>$tempErr
-status=$?
-set -e
-[ $status -ne 0 ]
-
-cat $tempErr
-
 cat > $tempRef <<EOF
 ECCODES ERROR   :  key 'a_deprecated_key' is unavailable in this version.
 ECCODES ERROR   :  Please use the following key(s):
 ECCODES ERROR   :  	- typeOfOriginalFieldValues
+ERROR: Key/value not found (message 1)
 EOF
 
-diff $tempRef $tempErr
+do_tests()
+{
+  qualifier=$1
+  echo "meta a_deprecated_key suppressed(typeOfOriginalFieldValues);  print \"[a_deprecated_key$qualifier]\";" > $tempFilt
+  set +e
+  ${tools_dir}/grib_filter $tempFilt $sample2  2>$tempErr
+  status=$?
+  set -e
+  [ $status -ne 0 ]
+  cat $tempErr
+  diff $tempRef $tempErr
+}
+
+do_tests ""
+do_tests ":i"
+do_tests ":d"
 
 
 # Clean up
